@@ -226,10 +226,6 @@ static void 	 gtk_source_buffer_real_apply_tag	(GtkTextBuffer		 *buffer,
 
 static void 	 gtk_source_buffer_real_mark_deleted	(GtkTextBuffer		 *buffer,
 							 GtkTextMark		 *mark);
-static gboolean	 gtk_source_buffer_find_bracket_match_with_limit (GtkSourceBuffer *buffer,
-								  GtkTextIter     *orig,
-								  GtkSourceBracketMatchType *result,
-								  gint             max_chars);
 
 static void	 gtk_source_buffer_real_undo		(GtkSourceBuffer	 *buffer);
 static void	 gtk_source_buffer_real_redo		(GtkSourceBuffer	 *buffer);
@@ -256,7 +252,6 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 {
 	GObjectClass        *object_class;
 	GtkTextBufferClass  *tb_class;
-	GType                param_types[2];
 
 	object_class 	= G_OBJECT_CLASS (klass);
 	tb_class	= GTK_TEXT_BUFFER_CLASS (klass);
@@ -286,9 +281,8 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_HIGHLIGHT_SYNTAX,
 					 g_param_spec_boolean ("highlight-syntax",
-							       _("Highlight Syntax"),
-							       _("Whether to highlight syntax "
-								 "in the buffer"),
+							       "Highlight Syntax",
+							       "Whether to highlight syntax in the buffer",
 							       TRUE,
 							       G_PARAM_READWRITE));
 
@@ -300,8 +294,8 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_HIGHLIGHT_MATCHING_BRACKETS,
 					 g_param_spec_boolean ("highlight-matching-brackets",
-							       _("Highlight Matching Brackets"),
-							       _("Whether to highlight matching brackets"),
+							       "Highlight Matching Brackets",
+							       "Whether to highlight matching brackets",
 							       TRUE,
 							       G_PARAM_READWRITE));
 
@@ -314,9 +308,8 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_MAX_UNDO_LEVELS,
 					 g_param_spec_int ("max-undo-levels",
-							   _("Maximum Undo Levels"),
-							   _("Number of undo levels for "
-							     "the buffer"),
+							   "Maximum Undo Levels",
+							   "Number of undo levels for the buffer",
 							   -1,
 							   G_MAXINT,
 							   -1,
@@ -325,27 +318,24 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_LANGUAGE,
 					 g_param_spec_object ("language",
-							      /* Translators: throughout GtkSourceView "language" stands
-							       * for "programming language", not "spoken language" */
-							      _("Language"),
-							      _("Language object to get "
-								"highlighting patterns from"),
+							      "Language",
+							      "Language object to get highlighting patterns from",
 							      GTK_SOURCE_TYPE_LANGUAGE,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 					 PROP_CAN_UNDO,
 					 g_param_spec_boolean ("can-undo",
-							       _("Can undo"),
-							       _("Whether Undo operation is possible"),
+							       "Can undo",
+							       "Whether Undo operation is possible",
 							       FALSE,
 							       G_PARAM_READABLE));
 
 	g_object_class_install_property (object_class,
 					 PROP_CAN_REDO,
 					 g_param_spec_boolean ("can-redo",
-							       _("Can redo"),
-							       _("Whether Redo operation is possible"),
+							       "Can redo",
+							       "Whether Redo operation is possible",
 							       FALSE,
 							       G_PARAM_READABLE));
 
@@ -359,16 +349,16 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_STYLE_SCHEME,
 					 g_param_spec_object ("style_scheme",
-							      _("Style scheme"),
-							      _("Style scheme"),
+							      "Style scheme",
+							      "Style scheme",
 							      GTK_SOURCE_TYPE_STYLE_SCHEME,
 							      G_PARAM_READWRITE));
 
 	g_object_class_install_property (object_class,
 	                                 PROP_UNDO_MANAGER,
 	                                 g_param_spec_object ("undo-manager",
-	                                                      _("Undo manager"),
-	                                                      _("The buffer undo manager"),
+	                                                      "Undo manager",
+	                                                      "The buffer undo manager",
 	                                                      GTK_SOURCE_TYPE_UNDO_MANAGER,
 	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
@@ -383,15 +373,12 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	g_object_class_install_property (object_class,
 					 PROP_IMPLICIT_TRAILING_NEWLINE,
 					 g_param_spec_boolean ("implicit-trailing-newline",
-							       _("Implicit trailing newline"),
+							       "Implicit trailing newline",
 							       "",
 							       TRUE,
 							       G_PARAM_READWRITE | G_PARAM_CONSTRUCT |
 							       G_PARAM_STATIC_STRINGS));
 
-	param_types[0] = GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE;
-	param_types[1] = GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE;
-
 	/**
 	 * GtkSourceBuffer::highlight-updated:
 	 * @buffer: the buffer that received the signal
@@ -404,12 +391,14 @@ gtk_source_buffer_class_init (GtkSourceBufferClass *klass)
 	 * updated (e.g. the no-spell-check context class).
 	 */
 	buffer_signals[HIGHLIGHT_UPDATED] =
-	    g_signal_newv ("highlight_updated",
-			   G_OBJECT_CLASS_TYPE (object_class),
-			   G_SIGNAL_RUN_LAST,
-			   NULL, NULL, NULL, NULL,
-			   G_TYPE_NONE,
-			   2, param_types);
+	    g_signal_new_class_handler ("highlight_updated",
+	                                G_OBJECT_CLASS_TYPE (object_class),
+	                                G_SIGNAL_RUN_LAST,
+	                                NULL, NULL, NULL, NULL,
+	                                G_TYPE_NONE,
+	                                2,
+	                                GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE,
+	                                GTK_TYPE_TEXT_ITER | G_SIGNAL_TYPE_STATIC_SCOPE);
 
 	/**
 	 * GtkSourceBuffer::source-mark-updated:
@@ -914,10 +903,9 @@ gtk_source_buffer_move_cursor (GtkTextBuffer     *buffer,
 
 	start = *iter;
 	previous_state = source_buffer->priv->bracket_match;
-	if (!gtk_source_buffer_find_bracket_match_with_limit (source_buffer,
-	                                                      &start,
-	                                                      &source_buffer->priv->bracket_match,
-	                                                      MAX_CHARS_BEFORE_FINDING_A_MATCH))
+	source_buffer->priv->bracket_match = _gtk_source_buffer_find_bracket_match (source_buffer, &start);
+
+	if (source_buffer->priv->bracket_match != GTK_SOURCE_BRACKET_MATCH_FOUND)
 	{
 		/* don't emit the signal at all if chars at previous and current
 		   positions are nonbrackets. */
@@ -1159,11 +1147,10 @@ get_context_class_mask (GtkSourceBuffer *buffer,
 	return ret;
 }
 
-static gboolean
-gtk_source_buffer_find_bracket_match_real (GtkSourceBuffer           *buffer,
-                                           GtkTextIter               *orig,
-					   GtkSourceBracketMatchType *result,
-                                           gint                       max_chars)
+/* note that we only look MAX_CHARS_BEFORE_FINDING_A_MATCH at the most */
+static GtkSourceBracketMatchType
+gtk_source_buffer_find_bracket_match_real (GtkSourceBuffer *buffer,
+                                           GtkTextIter     *orig)
 {
 	GtkTextIter iter;
 
@@ -1189,8 +1176,7 @@ gtk_source_buffer_find_bracket_match_real (GtkSourceBuffer           *buffer,
 
 	if (addition == 0)
 	{
-		*result = GTK_SOURCE_BRACKET_MATCH_NONE;
-		return FALSE;
+		return GTK_SOURCE_BRACKET_MATCH_NONE;
 	}
 
 	counter = 0;
@@ -1230,54 +1216,52 @@ gtk_source_buffer_find_bracket_match_real (GtkSourceBuffer           *buffer,
 		}
 	}
 	while (!gtk_text_iter_is_end (&iter) && !gtk_text_iter_is_start (&iter) &&
-		((char_cont < max_chars) || (max_chars < 0)));
+		(char_cont < MAX_CHARS_BEFORE_FINDING_A_MATCH));
 
 	if (found)
 	{
 		*orig = iter;
-		*result = GTK_SOURCE_BRACKET_MATCH_FOUND;
-	}
-	else if (char_cont >= max_chars && max_chars >= 0)
-	{
-		*result = GTK_SOURCE_BRACKET_MATCH_OUT_OF_RANGE;
-	}
-	else
-	{
-		*result = GTK_SOURCE_BRACKET_MATCH_NOT_FOUND;
+		return GTK_SOURCE_BRACKET_MATCH_FOUND;
 	}
 
-	return found;
+	if (char_cont >= MAX_CHARS_BEFORE_FINDING_A_MATCH)
+	{
+		return GTK_SOURCE_BRACKET_MATCH_OUT_OF_RANGE;
+	}
+
+	return GTK_SOURCE_BRACKET_MATCH_NOT_FOUND;
 }
 
 /* Note that we take into account both the character following the cursor and the
  * one preceding it. If there are brackets on both sides the one following the
  * cursor takes precedence.
  */
-static gboolean
-gtk_source_buffer_find_bracket_match_with_limit (GtkSourceBuffer           *buffer,
-                                                 GtkTextIter               *orig,
-                                                 GtkSourceBracketMatchType *result,
-                                                 gint                       max_chars)
+GtkSourceBracketMatchType
+_gtk_source_buffer_find_bracket_match (GtkSourceBuffer *buffer,
+                                       GtkTextIter     *orig)
 {
-	GtkTextIter iter;
+	GtkSourceBracketMatchType res;
 
-	if (gtk_source_buffer_find_bracket_match_real (buffer, orig, result, max_chars))
-	{
-		return TRUE;
-	}
+	res = gtk_source_buffer_find_bracket_match_real (buffer, orig);
 
-	iter = *orig;
-	if (!gtk_text_iter_starts_line (&iter) &&
-	    gtk_text_iter_backward_char (&iter))
+	if (res != GTK_SOURCE_BRACKET_MATCH_FOUND)
 	{
-		if (gtk_source_buffer_find_bracket_match_real (buffer, &iter, result, max_chars))
+		GtkTextIter iter;
+		iter = *orig;
+
+		if (!gtk_text_iter_starts_line (&iter) &&
+		    gtk_text_iter_backward_char (&iter))
 		{
-			*orig = iter;
-			return TRUE;
+			res = gtk_source_buffer_find_bracket_match_real (buffer, &iter);
+
+			if (res == GTK_SOURCE_BRACKET_MATCH_FOUND)
+			{
+				*orig = iter;
+			}
 		}
 	}
 
-	return FALSE;
+	return res;
 }
 
 /**
@@ -2522,6 +2506,102 @@ gtk_source_buffer_change_case (GtkSourceBuffer         *buffer,
 	g_free (new_text);
 }
 
+/* move to the end of the line excluding trailing spaces */
+static void
+move_to_line_text_end(GtkTextIter *iter)
+{
+	gint line;
+
+	line = gtk_text_iter_get_line (iter);
+
+	if (!gtk_text_iter_ends_line (iter))
+	{
+		gtk_text_iter_forward_to_line_end (iter);
+	}
+
+	while (gtk_text_iter_backward_char (iter) &&
+	       (gtk_text_iter_get_line (iter) == line))
+	{
+		gunichar ch;
+
+		ch = gtk_text_iter_get_char (iter);
+		if (!g_unichar_isspace (ch))
+		{
+			break;
+		}
+	}
+
+	gtk_text_iter_forward_char (iter);
+}
+
+/**
+ * gtk_source_buffer_join_lines:
+ * @buffer: a #GtkSourceBuffer.
+ * @start: a #GtkTextIter.
+ * @end: a #GtkTextIter.
+ *
+ * Joins the lines of text between the specified iterators.
+ *
+ * Since: 3.16
+ **/
+void
+gtk_source_buffer_join_lines (GtkSourceBuffer *buffer,
+                              GtkTextIter     *start,
+                              GtkTextIter     *end)
+{
+	GtkTextBuffer *text_buffer;
+	GtkTextMark *end_mark;
+
+	g_return_if_fail (GTK_SOURCE_IS_BUFFER (buffer));
+	g_return_if_fail (start != NULL);
+	g_return_if_fail (end != NULL);
+
+	if (gtk_text_iter_get_line (start) == gtk_text_iter_get_line (end))
+	{
+		return;
+	}
+
+	gtk_text_iter_order (start, end);
+
+	text_buffer = GTK_TEXT_BUFFER (buffer);
+	end_mark = gtk_text_buffer_create_mark (text_buffer, NULL, end, FALSE);
+
+	gtk_text_buffer_begin_user_action (text_buffer);
+
+	move_to_line_text_end (start);
+
+	while (gtk_text_iter_compare (start, end) < 0)
+	{
+		GtkTextIter iter;
+		gunichar ch;
+
+		iter = *start;
+
+		do
+		{
+			ch = gtk_text_iter_get_char (&iter);
+			if (!g_unichar_isspace (ch))
+			{
+				break;
+			}
+		} while (gtk_text_iter_forward_char (&iter));
+
+		if (!gtk_text_iter_is_end (&iter))
+		{
+			gtk_text_buffer_delete (text_buffer, start, &iter);
+			gtk_text_buffer_insert (text_buffer, start, " ", 1);
+		}
+
+		move_to_line_text_end (start);
+
+		gtk_text_buffer_get_iter_at_mark (text_buffer, end, end_mark);
+	}
+
+	gtk_text_buffer_end_user_action (text_buffer);
+
+	gtk_text_buffer_delete_mark (text_buffer, end_mark);
+}
+
 /**
  * gtk_source_buffer_set_undo_manager:
  * @buffer: a #GtkSourceBuffer.
