@@ -21,6 +21,7 @@
 
 #include "gtksourcegutterrenderer.h"
 #include "gtksourcegutterrenderer-private.h"
+#include "gtksourcestylescheme.h"
 #include "gtksourceview-typebuiltins.h"
 #include "gtksourceview-i18n.h"
 
@@ -477,13 +478,37 @@ renderer_draw_impl (GtkSourceGutterRenderer      *renderer,
 	if (renderer->priv->background_set)
 	{
 		cairo_save (cr);
-
 		gdk_cairo_rectangle (cr, background_area);
 		gdk_cairo_set_source_rgba (cr, &renderer->priv->background_color);
-
 		cairo_fill (cr);
 		cairo_restore (cr);
 	}
+	else if ((state & GTK_SOURCE_GUTTER_RENDERER_STATE_CURSOR) != 0 &&
+		 GTK_SOURCE_IS_VIEW (renderer->priv->view))
+	{
+		GtkSourceBuffer *buffer;
+		GtkSourceStyleScheme *style_scheme;
+		GdkRGBA line_color;
+
+		if (!gtk_source_view_get_highlight_current_line (GTK_SOURCE_VIEW (renderer->priv->view)))
+		{
+			return;
+		}
+
+		buffer = GTK_SOURCE_BUFFER (gtk_text_view_get_buffer (renderer->priv->view));
+		style_scheme = gtk_source_buffer_get_style_scheme (buffer);
+
+		if (style_scheme != NULL &&
+		    _gtk_source_style_scheme_get_current_line_color (style_scheme, &line_color))
+		{
+			cairo_save (cr);
+			gdk_cairo_rectangle (cr, background_area);
+			gdk_cairo_set_source_rgba (cr, &line_color);
+			cairo_fill (cr);
+			cairo_restore (cr);
+		}
+
+	}
 }
 
 static void
@@ -508,8 +533,8 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_VISIBLE,
 	                                 g_param_spec_boolean ("visible",
-	                                                       _("Visible"),
-	                                                       _("Visible"),
+	                                                       "Visible",
+	                                                       "Visible",
 	                                                       TRUE,
 	                                                       G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
 
@@ -521,8 +546,8 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_XPAD,
 	                                 g_param_spec_int ("xpad",
-	                                                   _("X Padding"),
-	                                                   _("The x-padding"),
+	                                                   "X Padding",
+	                                                   "The x-padding",
 	                                                   -1,
 	                                                   G_MAXINT,
 	                                                   0,
@@ -536,8 +561,8 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_YPAD,
 	                                 g_param_spec_int ("ypad",
-	                                                   _("Y Padding"),
-	                                                   _("The y-padding"),
+	                                                   "Y Padding",
+	                                                   "The y-padding",
 	                                                   -1,
 	                                                   G_MAXINT,
 	                                                   0,
@@ -553,8 +578,8 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_XALIGN,
 	                                 g_param_spec_float ("xalign",
-	                                                     _("X Alignment"),
-	                                                     _("The x-alignment"),
+	                                                     "X Alignment",
+	                                                     "The x-alignment",
 	                                                     -1,
 	                                                     1,
 	                                                     0,
@@ -570,8 +595,8 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_YALIGN,
 	                                 g_param_spec_float ("yalign",
-	                                                     _("Y Alignment"),
-	                                                     _("The y-alignment"),
+	                                                     "Y Alignment",
+	                                                     "The y-alignment",
 	                                                     -1,
 	                                                     1,
 	                                                     0,
@@ -705,8 +730,8 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_VIEW,
 	                                 g_param_spec_object ("view",
-	                                                      _("The View"),
-	                                                      _("The view"),
+	                                                      "The View",
+	                                                      "The view",
 	                                                      GTK_TYPE_TEXT_VIEW,
 	                                                      G_PARAM_READABLE));
 
@@ -722,8 +747,8 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_ALIGNMENT_MODE,
 	                                 g_param_spec_enum ("alignment-mode",
-	                                                    _("Alignment Mode"),
-	                                                    _("The alignment mode"),
+	                                                    "Alignment Mode",
+	                                                    "The alignment mode",
 	                                                    GTK_SOURCE_TYPE_GUTTER_RENDERER_ALIGNMENT_MODE,
 	                                                    GTK_SOURCE_GUTTER_RENDERER_ALIGNMENT_MODE_CELL,
 	                                                    G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
@@ -738,8 +763,8 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_WINDOW_TYPE,
 	                                 g_param_spec_enum ("window-type",
-	                                                    _("Window Type"),
-	                                                    _("The window type"),
+	                                                    "Window Type",
+	                                                    "The window type",
 	                                                    GTK_TYPE_TEXT_WINDOW_TYPE,
 	                                                    GTK_TEXT_WINDOW_PRIVATE,
 	                                                    G_PARAM_READABLE));
@@ -747,8 +772,8 @@ gtk_source_gutter_renderer_class_init (GtkSourceGutterRendererClass *klass)
 	g_object_class_install_property (object_class,
 	                                 PROP_SIZE,
 	                                 g_param_spec_int ("size",
-	                                                   _("Size"),
-	                                                   _("The size"),
+	                                                   "Size",
+	                                                   "The size",
 	                                                   0,
 	                                                   G_MAXINT,
 	                                                   0,
