@@ -174,6 +174,51 @@ test_change_case (void)
 	g_object_unref (buffer);
 }
 
+static void
+do_test_join_lines (GtkSourceBuffer *buffer,
+		    const gchar     *text,
+		    const gchar     *expected,
+		    gint             start_offset,
+		    gint             end_offset)
+{
+	GtkTextIter start;
+	GtkTextIter end;
+	gchar *changed;
+
+	gtk_text_buffer_set_text (GTK_TEXT_BUFFER (buffer), text, -1);
+
+	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (buffer), &start, start_offset);
+	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (buffer), &end, end_offset);
+
+	gtk_source_buffer_join_lines (buffer, &start, &end);
+
+	gtk_text_buffer_get_bounds (GTK_TEXT_BUFFER (buffer), &start, &end);
+	changed = gtk_text_buffer_get_text (GTK_TEXT_BUFFER (buffer), &start, &end, TRUE);
+
+	g_assert_cmpstr (changed, ==, expected);
+
+	g_free (changed);
+}
+
+static void
+test_join_lines (void)
+{
+	GtkSourceBuffer *buffer;
+
+	buffer = gtk_source_buffer_new (NULL);
+
+	do_test_join_lines (buffer, "some text", "some text", 0, -1);
+	do_test_join_lines (buffer, "some\ntext", "some text", 0, -1);
+	do_test_join_lines (buffer, "some\t  \n\t  text", "some text", 0, -1);
+	do_test_join_lines (buffer, "some\n\n\ntext", "some text", 0, -1);
+	do_test_join_lines (buffer, "some\ntext", "some\ntext", 0, 1);
+	do_test_join_lines (buffer, "some\ntext", "some\ntext", 6, -1);
+	do_test_join_lines (buffer, "some\ntext\nmore", "some text\nmore", 0, 6);
+	do_test_join_lines (buffer, "some\ntext\nmore", "some\ntext more", 6, -1);
+
+	g_object_unref (buffer);
+}
+
 int
 main (int argc, char** argv)
 {
@@ -184,6 +229,7 @@ main (int argc, char** argv)
 	g_test_add_func ("/Buffer/bug-634510", test_get_buffer);
 	g_test_add_func ("/Buffer/get-context-classes", test_get_context_classes);
 	g_test_add_func ("/Buffer/change-case", test_change_case);
+	g_test_add_func ("/Buffer/join-lines", test_join_lines);
 
 	return g_test_run();
 }
